@@ -6,7 +6,7 @@
 ;;         Naoya Yamashita <conao3@gmail.com>
 ;; Maintainer: Feng Shu <tumashu@163.com>
 ;; URL: https://github.com/tumashu/ivy-posframe
-;; Version: 0.6.0
+;; Version: 0.6.1
 ;; Keywords: abbrev, convenience, matching, ivy
 ;; Package-Requires: ((emacs "26.0") (posframe "1.0.0") (ivy "0.13.0"))
 
@@ -284,11 +284,16 @@ This variable is useful for `ivy-posframe-read-action' .")
              :internal-border-color (face-attribute 'ivy-posframe-border :background nil t)
              :override-parameters ivy-posframe-parameters
              :refposhandler ivy-posframe-refposhandler
+             :hidehandler #'ivy-posframe-hidehandler
              (funcall ivy-posframe-size-function))
       (ivy-posframe--add-prompt 'ignore)))
   (with-current-buffer ivy-posframe-buffer
     (setq-local truncate-lines ivy-truncate-lines)))
 
+(defun ivy-posframe-hidehandler (_)
+  "Hidehandler used by ivy-posframe."
+  (not (minibufferp)))
+
 (defun ivy-posframe-get-size ()
   "The default functon used by `ivy-posframe-size-function'."
   (list
@@ -375,6 +380,25 @@ This variable is useful for `ivy-posframe-read-action' .")
   (let ((ivy-read-action-function #'ivy-posframe-read-action-by-key))
     (ivy-posframe--dispatching-done)))
 
+(defun ivy-posframe--dispatching-call ()
+  "Select one of the available actions and call `ivy-call'."
+  (interactive)
+  (setq ivy-current-prefix-arg current-prefix-arg)
+  (let ((actions (copy-sequence (ivy-state-action ivy-last)))
+        (old-ivy-text ivy-text))
+    (unwind-protect
+        (when (ivy-read-action)
+          (ivy-set-text old-ivy-text)
+          (ivy-call))
+      (ivy-set-action actions)))
+  (ivy-posframe-shrink-after-dispatching))
+
+(defun ivy-posframe-dispatching-call ()
+  "Ivy-posframe's `ivy-dispatching-call'."
+  (interactive)
+  (let ((ivy-read-action-function #'ivy-posframe-read-action-by-key))
+    (ivy-posframe--dispatching-call)))
+
 (defun ivy-posframe-read-action ()
   "Ivy-posframe version `ivy-read-action'"
   (interactive)
@@ -632,7 +656,8 @@ This variable is useful for `ivy-posframe-read-action' .")
   :keymap '(([remap ivy-avy]              . ivy-posframe-avy)
             ([remap swiper-avy]           . ivy-posframe-swiper-avy)
             ([remap ivy-read-action]      . ivy-posframe-read-action)
-            ([remap ivy-dispatching-done] . ivy-posframe-dispatching-done))
+            ([remap ivy-dispatching-done] . ivy-posframe-dispatching-done)
+            ([remap ivy-dispatching-call] . ivy-posframe-dispatching-call))
   (if ivy-posframe-mode
       (mapc (lambda (elm)
               (advice-add (car elm) :around (cdr elm)))
